@@ -1,4 +1,4 @@
-predict.bbase.os <-
+predict_bbase_os <-
 function(object, newx) {
 	B <- predict(object, newx = newx)
 	B
